Description Usage Arguments Value Examples
title A maximum likelihood function
1 |
lfun |
The distribution function to sample from |
x |
A vector of measurements |
param |
A range of values to check for parameter |
... |
Additional plot details |
A list of data about a plot, and a plot
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.