myncurve: title A function that plots a normal curve with a lower-tail...

Description Usage Arguments Value Examples

View source: R/myncurve.R

Description

title A function that plots a normal curve with a lower-tail region

Usage

1
myncurve(mu, sigma, a)

Arguments

mu

The mean of the normal distribution

sigma

The standard deviation of the normal distribution

a

The upper bound of the probability

Value

A plot with a shaded region

Examples

1
## Not run: myncurve(mu=10,sigma=5,a=6)

scottie-curtis/MATH4753CURTIS documentation built on April 28, 2021, 9:23 p.m.